@@ -13,7 +13,7 @@ test_that("fill_ranges functions with date formats", {
     group = c("a", "a", "b", "b", "b"),
     start = c("2007-01-01", "2010-06-02", "2009-04-05", "2012-08-01", "2019-03-19"),
     end = c("2008-02-05", "2013-04-05", "2009-06-03", "2013-02-17", "2021-04-21"),
-    cost = c(143, 144, 105, 153, 124)
+    cost = c(143, 144, 105, 153, 124), stringsAsFactors = TRUE
   )
   
   output_date <- structure(
@@ -90,7 +90,7 @@ test_that("fill_ranges functions with date formats & no groups", {
     start = c("2007-01-01", "2010-06-02", "2014-01-01", "2015-01-01"),
     end = c("2008-02-05", "2013-04-05", "2014-12-31", "2016-12-31"),
     cost = c(143, 105, 153, 124),
-    score = c(99, 33, 44, 22)
+    score = c(99, 33, 44, 22), stringsAsFactors = TRUE
   )
   
   output_date <- structure(
@@ -127,7 +127,7 @@ test_that("fill_ranges functions with timestamp formats", {
     group = c("a", "a", "b", "b", "b"),
     start = c("2007-01-01 14:30:00", "2010-06-02 18:30:31", "2009-04-05 20:23:21", "2012-08-01 04:30:04", "2019-03-19 19:30:00"),
     end = c("2008-02-05 11:12:00", "2013-04-05 23:59:00", "2009-06-03 00:00:05", "2013-02-17 13:30:00", "2021-04-21 12:00:01"),
-    cost = c(143, 144, 105, 153, 124)
+    cost = c(143, 144, 105, 153, 124), stringsAsFactors = TRUE
   )
   
   output_times <- structure(
@@ -189,7 +189,7 @@ test_that("fill_ranges functions with fill", {
     start = c("2007-01-01", "2010-06-02", "2009-04-05", "2012-08-01", "2019-03-19", "2020-01-05", "2014-01-01", "2015-01-01"),
     end = c("2008-02-05", "2013-04-05", "2009-06-03", "2013-02-17", "2021-04-21", "2020-01-09", "2014-12-31", "2016-12-31"),
     cost = c(143, 144, 105, 153, 124, 105, 153, 124),
-    score = c(99, 33, 44, 22, 33, 105, 153, 124)
+    score = c(99, 33, 44, 22, 33, 105, 153, 124), stringsAsFactors = TRUE
   )
   
   output_fill <- structure(
